:mod:`lck.django.common.middleware`
===================================

.. automodule:: lck.django.common.middleware


Classes
-------

.. autoclass:: ActivityMiddleware
   :members:

.. autoclass:: AdminForceLanguageCodeMiddleware
   :members:

